summaryrefslogtreecommitdiff
path: root/src/gui/gtk
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2009-01-04 01:05:33 +0100
committerSebastien Helleu <flashcode@flashtux.org>2009-01-04 01:05:33 +0100
commit88aa905ee36bdfb631492968eb0f1691beae6235 (patch)
tree13e811a6e3be16a3ab2da1ff8cff1648b6b1e699 /src/gui/gtk
parent652bca1ffd565f53414f93e1a73afbe34cbc7923 (diff)
downloadweechat-88aa905ee36bdfb631492968eb0f1691beae6235.zip
Remove unused functions and prototypes
Diffstat (limited to 'src/gui/gtk')
-rw-r--r--src/gui/gtk/gui-gtk-chat.c8
-rw-r--r--src/gui/gtk/gui-gtk-window.c10
2 files changed, 10 insertions, 8 deletions
diff --git a/src/gui/gtk/gui-gtk-chat.c b/src/gui/gtk/gui-gtk-chat.c
index 2f985d6a9..d5fc0c078 100644
--- a/src/gui/gtk/gui-gtk-chat.c
+++ b/src/gui/gtk/gui-gtk-chat.c
@@ -473,9 +473,11 @@ gui_chat_draw_line (struct t_gui_buffer *buffer, struct t_gui_line *line)
struct t_gui_window *ptr_win;
unsigned char *message_without_color;
GtkTextIter start, end;
-
- ptr_win = gui_buffer_find_window (buffer);
- if (ptr_win)
+
+ (void) buffer;
+
+ //ptr_win = gui_buffer_find_window (buffer);
+ //if (ptr_win)
{
message_without_color = gui_color_decode ((unsigned char *)(line->message));
if (message_without_color)
diff --git a/src/gui/gtk/gui-gtk-window.c b/src/gui/gtk/gui-gtk-window.c
index 021aa4dbf..1ff046acc 100644
--- a/src/gui/gtk/gui-gtk-window.c
+++ b/src/gui/gtk/gui-gtk-window.c
@@ -418,7 +418,7 @@ gui_window_auto_resize (struct t_gui_window_tree *tree,
}
else
{
- if (tree->split_horiz)
+ if (tree->split_horizontal)
{
size1 = (height * tree->split_pct) / 100;
size2 = height - size1;
@@ -461,11 +461,11 @@ gui_window_refresh_windows ()
}
/*
* gui_window_split_horiz: split a window horizontally
*/
struct t_gui_window *
-gui_window_split_horiz (struct t_gui_window *window, int percentage)
+gui_window_split_horizontal (struct t_gui_window *window, int percentage)
{
struct t_gui_window *new_window;
int height1, height2;
@@ -506,11 +506,11 @@ gui_window_split_horiz (struct t_gui_window *window, int percentage)
}
/*
* gui_window_split_vertic: split a window vertically
*/
struct t_gui_window *
-gui_window_split_vertic (struct t_gui_window *window, int percentage)
+gui_window_split_vertical (struct t_gui_window *window, int percentage)
{
struct t_gui_window *new_window;
int width1, width2;
@@ -461,11 +461,11 @@ gui_window_refresh_windows ()
}
/*
- * gui_window_split_horiz: split a window horizontally
+ * gui_window_split_horizontal: split a window horizontally
*/
struct t_gui_window *
@@ -506,11 +506,11 @@ gui_window_split_horiz (struct t_gui_window *window, int percentage)
}
/*
- * gui_window_split_vertic: split a window vertically
+ * gui_window_split_vertical: split a window vertically
*/
struct t_gui_window *